package gui;
























































































































import javax.swing.*;












































import java.awt.Color;












































import java.awt.*;












































import java.util.ArrayList;











































import java.util.Calendar;







































import java.util.TimeZone;





































import berth.*;











































import com.jgoodies.forms.layout.*;











































import com.domainlanguage.time.*;












































import com.domainlanguage.timeutil.*;







































import java.util.HashMap;



















































/** Class for a customized panel
  *

  * Creates a panel that diplay the Berthes and the Ship that is allocated

  * The horisontal line at the top of the panel, represent date and timeline.

  * 

  * @author      Elin Marie Kristensen

  * @author      Mari Torgersrud Haug

  * @version     29.05.2006

  * @see         JettyWindow

  */

public class BerthPanel extends JPanel{











































    HashMap compMap;







    ArrayList timeList;







































    FormLayout form;











































    CellConstraints cc;











































    ColumnSpec[] cArray;







































 





   TimeZone zone;




































    ColumnSpec timeSpec;































    

/** Constructor for BerthPanel

  *

  * Creates the layout and structure for this panel. 

  * 

  */

    public BerthPanel(){












































        super();











































        setBackground(new Color(153,204,255));











































        zone = TimeZone.getDefault();































        timeSpec = new ColumnSpec(ColumnSpec.FILL, Sizes.pixel(4) , ColumnSpec.NO_GROW);































        RowSpec rSpec = new RowSpec(RowSpec.CENTER, Sizes.pixel(40), RowSpec.NO_GROW);











































        cArray = new ColumnSpec[1];









































        cArray[0] = new ColumnSpec(ColumnSpec.FILL, Sizes.pixel(350) , ColumnSpec.NO_GROW);









































        RowSpec[] rArray = new RowSpec[10];









































        rArray[0] = new RowSpec(RowSpec.CENTER, Sizes.pixel(20), RowSpec.NO_GROW);







































        rArray[1] = new RowSpec(RowSpec.CENTER, Sizes.pixel(20), RowSpec.NO_GROW);





























        for(int i = 2; i<rArray.length;i++){









































            rArray[i] = rSpec;









































        }









































        form = new FormLayout(cArray, rArray);









































        cc = new CellConstraints();       









































        setLayout(form);











































        makeTimeLine(8);







































        compMap = new HashMap();







   }











































   

/** Method that make a time line

 * 

 * This method creates the components that represent the timeline at the top of the panel

 *

 * @param number of days
 */    








































   public void makeTimeLine(int days){








































        JLabel clabel = new JLabel("Berth/Date");







































        clabel.setBorder(BorderFactory.createLineBorder(Color.black));







































        clabel.setOpaque(true);







































        clabel.setBackground(Color.lightGray);          







































        add(clabel,   cc.xywh(1, 1, 1, 2, CellConstraints.FILL, CellConstraints.FILL));







































        timeList = new ArrayList();





























        TimePoint startTime = SystemClock.now();







































        TimePoint time = startTime.backToMidnight(zone).plus(Duration.hours(1));





























        for(int i = 0; i<days;i++){







































            newDateColumn(time);





























            time = time.plus(Duration.days(1));





























        }







































   }








































   

/** Method that make a new date column

 * 

 * This method make a new column, that represent a day, with 24 hours, and therefor expand the panel

 * 
 * @param startTime the timepoint to start this date column
 */     





























   public void newDateColumn(TimePoint startTime){





























       int lastColumn = form.getColumnCount();





























       TimePoint time =  startTime;





























       for(int i = 0;i<24;i++){





























           newTimeColumn(time);





























           time = time.plus(Duration.hours(1));





























       }





























       add(makeDateLabel(time), cc.xywh(lastColumn +1 , 1,24,1, CellConstraints.FILL, CellConstraints.FILL));    





























   }































/** Method that make a new time column

 * 

 * This method make a new column, that represent an hour inside a date

 *

 * @param startTime the timepoint to start this hour column

 */    
































   public void newTimeColumn(TimePoint startTime){
































       form.appendColumn(timeSpec);
































       add(makeTimeLabel(startTime), cc.xy(form.getColumnCount(), 2, CellConstraints.FILL, CellConstraints.FILL));
































   }
































   





























/** Method that make a label, that represent an hour

 * 

 * This method make the label that represent an hour in the timeline

 *

 * @param startTime the timepoint to start this hour label

 * @return JLabel

 */     





























   public JLabel makeTimeLabel(TimePoint startTime){





























        TimePoint endTime = startTime.plus(Duration.hours(1));





























        TimeInterval colInterval = TimeInterval.over(startTime, endTime);





























        timeList.add(colInterval);   





























        Calendar cal = endTime.asJavaCalendar();





























        int hour = cal.get(Calendar.HOUR_OF_DAY);





























        String s = "";





























        JLabel label = new JLabel(s, JLabel.CENTER);





























        label.setBorder(BorderFactory.createLineBorder(Color.black));





























        label.setOpaque(true);





























        label.setBackground(Color.lightGray);





























        return label;





























   }





























   
































/** Method that make a label, that represent a date

 * 

 * This method make a label that represent a date in the timeline

 *

 * @param startTime the timepoint to start this date label

 * @return JLabel

 */    
































   public JLabel makeDateLabel(TimePoint startTime){
































        Calendar cal = startTime.asJavaCalendar();





























        int year = cal.get(Calendar.YEAR);





























        int month = cal.get(Calendar.MONTH) + 1;





























        int date = cal.get(Calendar.DATE);





























        String s = "" + month + "." + date;





























        JLabel label = new JLabel(s, JLabel.CENTER);





























        label.setBorder(BorderFactory.createLineBorder(Color.black));





























        label.setOpaque(true);





























        label.setBackground(Color.lightGray);





























        return label;





























    }





























    

/** Method that make the representatiom of Berth

 * 

 * This method make a label for each Berth with text name and product, 

 * and place them vertically to the left of the panel. 

 *

 * @param list with Berth agents

 */       





























    public void makeBerths(ArrayList list) {





























        for (int i = 0; i < list.size(); i++) {





























            Berth tempBerth = (Berth) list.get(i);





























            ArrayList liftingArmList = tempBerth.getLiftingArmList();



























            String s = tempBerth.getAgentName() + " [";



























            for(int j = 0; j < liftingArmList.size(); j ++){






















                LiftingArm liftingArm = (LiftingArm)liftingArmList.get(j);






















                ArrayList productList = liftingArm.getProductList();






















                for(int k = 0; k < productList.size(); k++){



























                    String product = (String)productList.get(k);



























                    s = s + " " + product;



























                }





















                





















            }


























            s = s + " ]: ";





























            JLabel label = new JLabel(s);





























            label.setBorder(BorderFactory.createLineBorder(Color.black));





























            label.setOpaque(true);





























            label.setBackground(Color.lightGray);





























            add(label, cc.xy(1, i + 3, CellConstraints.FILL,CellConstraints.FILL));





























        }





























        setVisible(true);





























    }

    





























/** Method that provide that a ship is displayed 

 * 

 * @param Ship the ship that should be displayed

 * @param int id for the berth that the ship is allocated to

 */      





























    public void displayShip(int berthId, Ship ship) throws IndexOutOfBoundsException {































        addShipToBerth(berthId, ship);



















        setVisible(true);



















    }



















    

/** Method that provide that a ship is displayed on the right place

 * 

 * Find the location in the panel where this Ship should be displayed,

 * make a label representation of the ship an add this on the right place

 *

 * @param Ship the ship that should be displayed

 * @param int id for the berth that the ship is allocated to

 */         



















    public void addShipToBerth(int berthID, Ship ship){



















                String shipName = ship.getName();





























                removeShipComp(shipName);





                TimePoint startTime = ship.getDelegatedArrivalTime();





























                TimePoint endTime = ship.getDepartureTime();









                System.out.println("SHIPNAME: "+shipName+" startTid: " + startTime.toString()+" sluttTid: " + endTime.toString());





























                int startColumn = getColumn(startTime);





























                int endComlumn = getColumn(endTime);





























                int colSpan = endComlumn - startColumn + 1;





























                JLabel shipLabel = new JLabel(shipName);





























                shipLabel.setBorder(BorderFactory.createLineBorder(Color.black));





























                shipLabel.setOpaque(true);





























                shipLabel.setBackground(new Color(153, 255, 153));





























                shipLabel.setVisible(true);





























                try {





























                    add(shipLabel, cc.xywh(startColumn, berthID + 3, colSpan, 1));





























                    compMap.put(shipName,shipLabel);







                    







                } catch (IndexOutOfBoundsException e) {





























                    throw new IndexOutOfBoundsException();





























                }





























    }





















/** Method that look up the column for a given time

 * 

 * Search threw a list with timeintervals and find the right for the timepoint.

 * Identify the column that represent this TimeInterval

 *

 * @param Timepoint time

 * @return int

 */      













































    public int getColumn(TimePoint time){





























        for (int i = 0; i < timeList.size(); i++) {





























            TimeInterval tempInt = (TimeInterval) timeList.get(i);





























            if (!time.isBefore(tempInt) && !time.isAfter(tempInt)) {





























                return i + 2;





























            }





























        }





























        TimePoint lastAdded = ((TimeInterval)timeList.get(timeList.size()-1)).end();




























        while(!time.isBefore((TimeInterval)timeList.get(timeList.size()-1))){




























            newDateColumn(lastAdded);




























            lastAdded = lastAdded.plus(Duration.days(1));



























        }        




























        return getColumn(time);





























    }































/** Method that remove a ship component

 * 

 * This method find the label that represent a ship, and removes it from this panel

 *

 * @param String shipName for the ship to be removed

 */  




















   public void removeShipComp(String shipName){







       try{





        JLabel shipLabel = (JLabel)compMap.remove(shipName);







        shipLabel.setVisible(false);







        form.removeLayoutComponent(shipLabel);







        remove(shipLabel); 







        }





        catch(NullPointerException e){





        }





   }







   


















}





























             





























             





























             





























             