package gui;














































































import java.awt.*;
























































































































import javax.swing.*;
































































































import java.util.ArrayList;





































































































import com.jgoodies.forms.layout.*;





























































































import com.domainlanguage.time.*;





































































































import com.domainlanguage.timeutil.*;









































































































/** Class for customized user interface window.




  *




  * Creates a ShipPanel and a BerthPanel. 




  * Manage det actions related to changes in the window.




  * 




  * @author      Elin Marie Kristensen




  * @author      Mari Torgersrud Haug




  * @version     18.05.2006




  * @see         BerthPanel, ShipPanel, Screen




  */









public class JettyWindow extends JFrame{





























































































    private JLabel lblClock;










































    private JLabel msgLabel;





























































































    private BerthPanel berthPanel;




















































    JScrollPane scroll;




























    private ArrayList shipList;

















































































    private ShipPanel shipPanel;








































    private Screen screen;








































    Container c;








































    




/** Constructor for JettyWindow




  *




  * Creates the layout and components for this window. 




  * 




  * @param   name   the title for the window




  * @param   screen a view in the agent system, coupling this interface to the rest of the system




  */








































 




    public JettyWindow(String name, Screen scr){








































       super(name);








































       screen = scr;








































       c = getContentPane();








































       FormLayout containerLayout = new FormLayout("left:10px:NONE, left:pref:GROW, left:10px:NONE","c:10px:none, c:40px:none, c:10px:none, c:pref:grow, c:10px:none,c:40px:none, c:10px:none,c:pref:grow, c:20px:none");




       CellConstraints cc = new CellConstraints();  






































       c.setLayout(containerLayout);








































       shipList = new ArrayList();








































       makeLabels();







































       c.add(lblClock, cc.xy(2,2));







































       shipPanel = new ShipPanel(this);        








































       c.add(shipPanel, cc.xy(2,4));    






































       berthPanel = new BerthPanel();








































       scroll = new JScrollPane(berthPanel, JScrollPane.VERTICAL_SCROLLBAR_NEVER, JScrollPane.HORIZONTAL_SCROLLBAR_AS_NEEDED); 








































       c.add(scroll, cc.xy(2,8));








































       c.add(msgLabel, cc.xy(2,6));







































       pack();








































       setVisible(true);








































  }








































/** Method that creates JLabels, that display messages



  *




  */












































































    public void makeLabels(){




















































        lblClock = new JLabel("Time: "+SystemClock.now().toString());







































        lblClock.setBorder(BorderFactory.createLineBorder(Color.black));






































        msgLabel = new JLabel("");







































        msgLabel.setForeground(Color.red);







































    }







































    
































/** Method that instanciate the ShipPanel




  *




  * @param list an ArrayList containing the ships




  * @see ShipPanel




  */  








































    public void initShipPanel(ArrayList list){









































        shipPanel.makeShipRows(list);








































        setVisible(true);









    }





    




/** Method that instanciate the BerthPanel




  *




  * @param list an ArrayList containing the berths




  * @see BerthPanel




  */  





































    








































    public void initBerthPanel(ArrayList list){

































































        berthPanel.makeBerths(list);




















































        scroll.setPreferredSize(new Dimension(berthPanel.getWidth(),berthPanel.getHeight()+18));









































        setVisible(true);

































































    }

























































/** Method for submitting a new ship arrival




  *  




  * This method is called when, a new ship is registrated using this ship's submit button in the shipPanel.




  * The ship is forward to the screen view, that post an event to the agent system.




  *




  * @param ship the ship that is submitted




  * @param hours hours until shipArrival




  * @see Screen




  *




  */ 




































    public void submitShip(Ship ship, int hours){







































        TimePoint arrivalTime = SystemClock.now().plus(Duration.hours(hours));




































        ship.setArrivalTime(arrivalTime);




































        message("Submitting ship.."+ship.getName()+", please wait.");
































        screen.submitShip(ship);




































    }




































    




/** Method for removing a ship




  *  




  * This method is called when, a update for a ship is registrated using this ship's submit button in the shipPanel.




  * The ship is forward to the screen view, that post an event to the agent system.




  *




  * @param ship the ship that is updated




  * @param hours hours until shipArrival




  * @see Screen




  */ 




































    public void mooveShip(Ship ship, int hours){

























        TimePoint arrivalTime = SystemClock.now().plus(Duration.hours(hours));

























        ship.setArrivalTime(arrivalTime);

























        message("Reallocating ship.."+ship.getName()+", please wait.");

























        berthPanel.removeShipComp(ship.getName());














        screen.mooveShip(ship);

























    }

























    

























/** Method for displaying a ship




  *  




  * This method is called when the ship is given an allocation in the agent system.




  * This method forward the information to the berthPanel, which displays the ship




  *




  * @param berthId identification for the berth that has been delegated the responsibility




  * @param ship the ship to be displayed




  * @see BerthPanel




  *




  */ 





















    public void insertShip(int berthId, Ship ship){

































        if(berthId==100){



















            message("Allocation failed.");



















            ship.newShip();
















            shipPanel.resetShip(ship);


















        }



















        else{






























            try{
































                berthPanel.displayShip(berthId, ship);
































                shipPanel.resetShip(ship);










                lblClock.setText("Time: "+SystemClock.now().toString());
































                message("Allocation finished.");
































            }catch(IndexOutOfBoundsException e){
































                message("The date is too far ahead.");
































            }
































            shipPanel.receiveShip();































            
setVisible(true);
































        }






























   }






































/** Method for displaying a message in the JettyWindow




  *  




  * The method display a given string in the message label




  *




  * @param message a message String




  */    




   














   public void message(String message){































         msgLabel.setText(message);































         msgLabel.setVisible(true);































    }












































































}