package gui;



import javax.swing.*;

import java.awt.Component;

import java.awt.Color;

import javax.swing.table.*;


/** Class for making a customized ComboBox renderer
  *
  * This class is used by the comboBoxes in the table in ShipPanel
  * It implements the TableCellRenderer
  * 
  * @author      Elin Marie Kristensen
  * @author      Mari Torgersrud Haug
  * @version     29.05.2006
  * @see         ShipPanel
  */

public class ComboRenderer extends JComboBox implements TableCellRenderer{


 /** Constructor for the ComboRenderer
  * 
  * Sets the reenderer to be opaque
  * 
  * @param String items[] string values to be displayed by this reenderer
  */ 
  public ComboRenderer(String[] items){

    super(items);  

    setOpaque(true);

  }



 /** Method that make this reenderers component and returns a reference
  * 
  * @param JTable table that is asking the reenderer to reender
  * @param value the value of the cell to be reendered
  * @param boolean isSelected is true if the cell is to be rendered with highlighting
  * @param boolean hasFocus true if cell has focus
  * @param row of the cell being reendered
  * @param column of the cell being reendered
  * 
  * @return Component
  */  

  public Component getTableCellRendererComponent(JTable table, Object value, boolean isSelected, boolean hasFocus, int row, int column) {

   if (isSelected) {

      setForeground(table.getSelectionForeground());

      super.setBackground(table.getSelectionBackground());

    } 

    else {

      setForeground(table.getForeground());

    setBackground(Color.lightGray);

    }

    setSelectedItem(value);

    return this;

}

}

