package gui;

import javax.swing.*;

import java.awt.Component;

import java.awt.event.ActionListener;

import java.awt.event.ActionEvent;


/** Class for making a customized button editor
  *
  * This class is used by the submitButtons in the table in ShipPanel
  * It extends the DefaultCellEditor, and implement how the buttons should react when 
  * they are pushed.
  * 
  * @author      Elin Marie Kristensen
  * @author      Mari Torgersrud Haug
  * @version     18.05.2006
  * @see         ShipPanel
  */
public class SubmitEditor extends DefaultCellEditor{    

    protected JButton button;    

    private String label; 

    private int row = 100;

    private ShipPanel shipPanel;

    public boolean isPushed;

/** Constructor for the SubmitEditor
  * 
  * @param JCheckBox checkBox needed for the constructor in DefaultCellEditor
  * @param ShipPanel shipPanel reference
  * 
  */      

    public SubmitEditor(JCheckBox checkBox, ShipPanel shipPanel) {        

        super(checkBox); 

        this.shipPanel = shipPanel;

        button = new JButton();

        button.setOpaque(true);        

        button.addActionListener(new ActionListener() { 

            public void actionPerformed(ActionEvent e) {

                updateShip(row);

                fireEditingStopped();

              }        

        });    

   }    

 /** Method for updating information about ship
  * 
  * This method make the shipPanel update information about a ship
  * 
  * @param int row the row wich has received new information
  */     

   public void updateShip(int row){

      shipPanel.updateShip(row);

   }


/** Method that make this editors component and returns a reference
  * 
  * @param JTable table that is asking the editor to edit
  * @param value of the cell to be edited
  * @param boolean isSelected is true if the cell is to be rendered with highlighting
  * @param row of the cell being edited
  * @param  column of the cell being edited 
  * 
  * @return Component
  */  
   public Component getTableCellEditorComponent(JTable table, Object value, boolean isSelected, int row, int column) {            

        if (isSelected) {                

            button.setForeground(table.getSelectionForeground());               

            button.setBackground(table.getSelectionBackground());            

        }

        else { 

            button.setForeground(table.getForeground()); 

            button.setBackground(table.getBackground());  

        }

        this.row = row;

        return button; 

    }   
    
 /** Method nvoked when a component gains the keyboard focus.
  * 
  * The method call the method from the super class
  * 
  * @return boolean
  */     
 

    public boolean stopCellEditing() {

        return super.stopCellEditing();

    }

    

 /** Method that forwards the message from the CellEditor to the delegate.
  *
  * The method call the method from the super class
  * 
  */  
    protected void fireEditingStopped() {

        super.fireEditingStopped();

    }



}